
import React from 'react';
import { Job } from '@/PersonalDataTypes';
import { Accordion, Row } from 'react-bootstrap';
import { JobListProps } from './types';
import JobTags from './JobTags';
import md from '../Markdown';


export type Props = {
  heading: string,
} & JobListProps

const defaultProps = {
  entriesPerRow: 2,
  currentHeading: 'Currently',
}

export default function JobsAccordion(props: JobListProps) {
  const {jobs} = props
  const config = {...defaultProps, ...props}
  function JobTitle(props: {job: Job, heading?: string}) {
    const {job, heading} = props
    return (
      <div>
        <div><strong>{job.position}</strong></div>
        <div>{[job.company, job.timerange].filter(x => x).join(', ')}</div>
        {heading && (<div>({heading})</div>)}
      </div>
    )
  }
  return (
    <Accordion defaultActiveKey={jobs.current ? 'current' : 'previous-0'}>
      {jobs.current && (
      <Accordion.Item eventKey="current">
        <Accordion.Header><JobTitle heading={config.currentHeading} job={jobs.current} /> </Accordion.Header>
        <Accordion.Body>
          {md(jobs.current.description)}
          {jobs.current.tags && <JobTags tags={jobs.current.tags} />}
        </Accordion.Body>
      </Accordion.Item>
      )}
      {jobs.previous?.map((job, index) => (
      <Accordion.Item eventKey={`previous-${index}`} key={index}>
        <Accordion.Header><JobTitle job={job} /></Accordion.Header>
        <Accordion.Body className='multiline'>
        {md(job.description)}
        {job.tags && <JobTags tags={job.tags} />}
        </Accordion.Body>
      </Accordion.Item>
      ))}
    </Accordion>
  )
}
